import { TrackEvent, IdentifyEvent, SegmentConfig } from "../types/segment.js";
export declare class SegmentTrackingClient {
    private client;
    private writeKey;
    constructor(config: SegmentConfig);
    /**
     * Send a track event to Segment
     */
    track(event: TrackEvent): Promise<void>;
    /**
     * Send an identify event to Segment
     */
    identify(event: IdentifyEvent): Promise<void>;
    /**
     * Track AI conversation started event
     */
    trackAIConversationStarted(userId: string, conversationId: string, properties?: Record<string, any>, anonymousId?: string): Promise<void>;
    /**
     * Track AI conversation ended event
     */
    trackAIConversationEnded(userId: string, conversationId: string, properties?: Record<string, any>, anonymousId?: string): Promise<void>;
    /**
     * Track AI message sent event
     */
    trackAIMessageSent(userId: string, conversationId: string, messageContent: string, properties?: Record<string, any>, anonymousId?: string): Promise<void>;
    /**
     * Track AI response received event
     */
    trackAIResponseReceived(userId: string, conversationId: string, responseContent: string, properties?: Record<string, any>, anonymousId?: string): Promise<void>;
    /**
     * Track AI feedback event
     */
    trackAIFeedback(userId: string, conversationId: string, messageId: string, feedbackType: "thumbs_up" | "thumbs_down" | "rating", feedbackValue?: number, feedbackText?: string, anonymousId?: string): Promise<void>;
    /**
     * Batch track multiple events
     */
    batchTrack(events: TrackEvent[]): Promise<void>;
}
//# sourceMappingURL=tracking-client.d.ts.map