import dotenv from "dotenv";
// Load environment variables
dotenv.config();
// Default values for required environment variables
const DEFAULT_CONFIG = {};
export function loadConfig() {
    const requiredEnvVars = [
        "SEGMENT_PROFILE_API_TOKEN",
        "SEGMENT_TRACKING_WRITE_KEY",
        "SEGMENT_WORKSPACE_ID",
        "SEGMENT_SPACE_ID",
    ];
    // Use environment variables if available, otherwise use defaults
    requiredEnvVars.forEach((varName) => {
        if (!process.env[varName]) {
            process.env[varName] = DEFAULT_CONFIG[varName];
            console.warn(`Warning: Using default value for ${varName}. Please set this in your .env file for production use.`);
        }
    });
    // Determine transport mode based on environment
    const transport = process.env.MCP_TRANSPORT || "stdio";
    return {
        profileApiToken: process.env.SEGMENT_PROFILE_API_TOKEN,
        trackingWriteKey: process.env.SEGMENT_TRACKING_WRITE_KEY,
        workspaceId: process.env.SEGMENT_WORKSPACE_ID,
        spaceId: process.env.SEGMENT_SPACE_ID,
        profileApiBaseUrl: process.env.SEGMENT_PROFILE_API_BASE_URL ||
            "https://profiles.segment.com",
        trackingApiBaseUrl: process.env.SEGMENT_TRACKING_API_BASE_URL || "https://api.segment.io/v1",
        logLevel: process.env.LOG_LEVEL || "info",
        rateLimit: parseInt(process.env.API_RATE_LIMIT_PER_MINUTE || "60", 10),
        transport,
        httpPort: parseInt(process.env.HTTP_PORT || "3000", 10),
        httpHost: process.env.HTTP_HOST || "0.0.0.0",
    };
}
export function validateConfig(config) {
    if (!config.profileApiToken) {
        throw new Error("Profile API token is required");
    }
    if (!config.trackingWriteKey) {
        throw new Error("Tracking write key is required");
    }
    if (!config.workspaceId) {
        throw new Error("Workspace ID is required");
    }
    if (!config.spaceId) {
        throw new Error("Space ID is required");
    }
}
//# sourceMappingURL=config.js.map